@@ -143,7 +143,7 @@ class GoEthereumPersonalModuleTest:
         unlockable_account_dual_type: ChecksumAddress,
         unlockable_account_pw: str,
     ) -> None:
-        assert web3.eth.getBalance(unlockable_account_dual_type) > web3.toWei(1, 'ether')
+        assert web3.eth.get_balance(unlockable_account_dual_type) > web3.toWei(1, 'ether')
         txn_params: TxParams = {
             'from': unlockable_account_dual_type,
             'to': unlockable_account_dual_type,
@@ -153,7 +153,7 @@ class GoEthereumPersonalModuleTest:
         }
         txn_hash = web3.geth.personal.send_transaction(txn_params, unlockable_account_pw)
         assert txn_hash
-        transaction = web3.eth.getTransaction(txn_hash)
+        transaction = web3.eth.get_transaction(txn_hash)
 
         assert is_same_address(transaction['from'], cast(ChecksumAddress, txn_params['from']))
         assert is_same_address(transaction['to'], cast(ChecksumAddress, txn_params['to']))
@@ -168,7 +168,7 @@ class GoEthereumPersonalModuleTest:
         unlockable_account_pw: str,
     ) -> None:
         with pytest.warns(DeprecationWarning):
-            assert web3.eth.getBalance(unlockable_account_dual_type) > web3.toWei(1, 'ether')
+            assert web3.eth.get_balance(unlockable_account_dual_type) > web3.toWei(1, 'ether')
             txn_params: TxParams = {
                 'from': unlockable_account_dual_type,
                 'to': unlockable_account_dual_type,
@@ -178,7 +178,7 @@ class GoEthereumPersonalModuleTest:
             }
             txn_hash = web3.geth.personal.sendTransaction(txn_params, unlockable_account_pw)
             assert txn_hash
-            transaction = web3.eth.getTransaction(txn_hash)
+            transaction = web3.eth.get_transaction(txn_hash)
 
             assert is_same_address(transaction['from'], cast(ChecksumAddress, txn_params['from']))
             assert is_same_address(transaction['to'], cast(ChecksumAddress, txn_params['to']))
@@ -459,7 +459,7 @@ class ParityPersonalModuleTest():
         unlockable_account_dual_type: ChecksumAddress,
         unlockable_account_pw: str,
     ) -> None:
-        assert web3.eth.getBalance(unlockable_account_dual_type) > web3.toWei(1, 'ether')
+        assert web3.eth.get_balance(unlockable_account_dual_type) > web3.toWei(1, 'ether')
         txn_params: TxParams = {
             'from': unlockable_account_dual_type,
             'to': unlockable_account_dual_type,
@@ -469,7 +469,7 @@ class ParityPersonalModuleTest():
         }
         txn_hash = web3.parity.personal.send_transaction(txn_params, unlockable_account_pw)
         assert txn_hash
-        transaction = web3.eth.getTransaction(txn_hash)
+        transaction = web3.eth.get_transaction(txn_hash)
 
         assert is_same_address(transaction['from'], cast(ChecksumAddress, txn_params['from']))
         assert is_same_address(transaction['to'], cast(ChecksumAddress, txn_params['to']))
@@ -484,7 +484,7 @@ class ParityPersonalModuleTest():
         unlockable_account_pw: str,
     ) -> None:
         with pytest.warns(DeprecationWarning):
-            assert web3.eth.getBalance(unlockable_account_dual_type) > web3.toWei(1, 'ether')
+            assert web3.eth.get_balance(unlockable_account_dual_type) > web3.toWei(1, 'ether')
             txn_params: TxParams = {
                 'from': unlockable_account_dual_type,
                 'to': unlockable_account_dual_type,
@@ -494,7 +494,7 @@ class ParityPersonalModuleTest():
             }
             txn_hash = web3.parity.personal.sendTransaction(txn_params, unlockable_account_pw)
             assert txn_hash
-            transaction = web3.eth.getTransaction(txn_hash)
+            transaction = web3.eth.get_transaction(txn_hash)
 
             assert is_same_address(transaction['from'], cast(ChecksumAddress, txn_params['from']))
             assert is_same_address(transaction['to'], cast(ChecksumAddress, txn_params['to']))
